#!/bin/bash

force_reset=0
if [ $# -ne 0 ]
then
	if [[ "$1" == "--force-reset" ]]
	then
	force_reset=1
	fi
fi
echo "force reset = " $force_reset

# Do key tab auto update for host machine
if [ $force_reset -eq 1 ]
then
	/opt/novell/bin/novell-ad-util --auto-reset --force-reset
else
	/opt/novell/bin/novell-ad-util --auto-reset
fi

# Do key tab update for cluster resources

# Check whether this node is a cluster node
`/sbin/cluster view  > /dev/null 2>&1`
if [ $? != 0 ];
then
        echo "This is not a cluster node"
        exit 1
fi

# Find the name of this node
thisnode=`/sbin/cluster view | grep "This node" | cut -d" " -f3`

list=`grep -r "novcifs"  /var/opt/novell/ncs/*.load`

# Extract each resource info and operate on it
while read -r line; do
	resourceDN=`echo $line | cut -d":" -f2 | cut -d"\"" -f2`
	echo $resourceDN
	resourceName=`echo $line | cut -d":" -f1 | cut -d"/" -f6 | cut -d"." -f1`
	echo $resourceName
	# check is resource is running and live on this node
	string=`/sbin/cluster resources | grep "$resourceName"`
	if test -z "$string"
	then
		echo "Resource $resourceName does not seems to be active. skipping it"
		continue
	fi
	i=0
	for token in $string;
	do
		if [ $i == 1 ]; then
			state=$token
		elif [ $i == 2 ]; then
			livesInNode=$token
		fi
		i=$((i+1))
	done
	echo $state
	echo $livesInNode
	if [ $livesInNode != $thisnode ]; then
		echo "Resource $resourceName lives in a different node($livesInNode). Not updating the keytab"
		continue
	fi
	# Now start updating keytab for this resource
	if [ $force_reset -eq 1 ]
	then
		/opt/novell/bin/novell-ad-util --auto-reset --cluster-resource $resourceDN --force-reset
	else
		/opt/novell/bin/novell-ad-util --auto-reset --cluster-resource $resourceDN
	fi
	/opt/novell/bin/novell-ad-util --offline --cluster-resource $resourceDN
done <<< "$list"
